<?php

/**
 * @file
 * Contains \Drupal\uvf_migrate\Plugin\migrate\source\Vocabulary.
 */

namespace Drupal\uvf_migrate\Plugin\migrate\source;

use Drupal\migrate\Row;
use Drupal\migrate\Plugin\migrate\source\SqlBase;

/**
 * Drupal 9 vocabularies source from database.
 *
 * @MigrateSource(
 *   id = "custom_taxonomy_vocabulary",
 *   source_provider = "taxonomy"
 * )
 */
class Vocabulary extends SqlBase
{
    /**
     * {@inheritdoc}
     */
    public function query()
    {
        $query = $this->select('taxonomy_term_field_data', 'v')
            ->fields('v', ['tid','name','description__value','weight']);
        return $query;
    }

    /**
     * {@inheritdoc}
     */
    public function fields()
    {
        return [
            'tid' => $this->t('The vocabulary ID.'),
            'name' => $this->t('The name of the vocabulary.'),
            'description__value' => $this->t(
                'The description of the vocabulary.'
            ),
            'weight' => $this->t(
                'The weight of the vocabulary in relation to other vocabularies.'
            ),
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function getIds()
    {
        $ids['tid']['type'] = 'integer';
        return $ids;
    }
}
